/*===========================================================================
Project:  Inequality, Income Dynamics, and Worker Transitions:The Case of Mexico
Author:   Daniela Puggioni, Mariana Calderón, Alfonso Cebreros Zurita, León
Fernández Bujanda, José Antonio Inguanzo González, and David Jaume 
Program name: 11.build_transitions_treateds2.do
Dependencies: Banco de Mexico
Description: Builds events for treatment group with augmented sample:
workers with at least two spells of formal employment
===========================================================================*/

glo carpeta 	     "S:\PartB\B.1TransitionsInOutIMSS\Replication"
glo sourcedata	     "$carpeta/data/source"
glo constructeddata	 "$carpeta/data/constructed"
glo figures 	     "$carpeta/figures"
glo logfiles	     "$carpeta/log"
glo ster		     "$carpeta/ster"
glo tables		     "$carpeta/tables"
glo code	         "$carpeta/code"

*Bring spells data
use "$constructeddata/spells.dta", replace


*Keep workers with at least two spells of formal employment
	drop if spellsInactivo==0	
	sort individuo anio
	keep if _spell==1 | _spell==2 | _spell==3
		*spell==1 -> first active spell
		*spell==2 -> first inactive spell
		*spell==3 -> second active spell
	
	
*Generate events
sort individuo anio
gen evento=.
	*Last observed wage before exit 
	replace evento=13 if _spell==1 & _end==1 
	*First observed wage when comming back
	replace evento=14 if _spell==3 & _seq==1
		*Before exiting IMSS
		replace evento=0 if evento[_n+13]==13 & individuo==individuo[_n+13]
		replace evento=1 if evento[_n+12]==13 & individuo==individuo[_n+12]
		replace evento=2 if evento[_n+11]==13 & individuo==individuo[_n+11]
		replace evento=3 if evento[_n+10]==13 & individuo==individuo[_n+10]
		replace evento=4 if evento[_n+9]==13  & individuo==individuo[_n+9]
		replace evento=5 if evento[_n+8]==13  & individuo==individuo[_n+8]
		replace evento=6 if evento[_n+7]==13  & individuo==individuo[_n+7]
		replace evento=7 if evento[_n+6]==13  & individuo==individuo[_n+6]
		replace evento=8 if evento[_n+5]==13  & individuo==individuo[_n+5]
		replace evento=9 if evento[_n+4]==13  & individuo==individuo[_n+4]
		replace evento=10 if evento[_n+3]==13  & individuo==individuo[_n+3]
		replace evento=11 if evento[_n+2]==13  & individuo==individuo[_n+2]
		replace evento=12 if evento[_n+1]==13  & individuo==individuo[_n+1]
		*When coming back
		replace evento=15 if evento[_n-1]==14 & individuo==individuo[_n-1]
		replace evento=16 if evento[_n-2]==14 & individuo==individuo[_n-2]
		replace evento=17 if evento[_n-3]==14 & individuo==individuo[_n-3]
		replace evento=18 if evento[_n-4]==14 & individuo==individuo[_n-4]
		replace evento=19 if evento[_n-5]==14 & individuo==individuo[_n-5]
		replace evento=20 if evento[_n-6]==14 & individuo==individuo[_n-6]
		replace evento=21 if evento[_n-7]==14 & individuo==individuo[_n-7]
		replace evento=22 if evento[_n-8]==14 & individuo==individuo[_n-8]
		replace evento=23 if evento[_n-9]==14 & individuo==individuo[_n-9]
		replace evento=24 if evento[_n-10]==14 & individuo==individuo[_n-10]
		replace evento=25 if evento[_n-11]==14 & individuo==individuo[_n-11]
		replace evento=26 if evento[_n-12]==14 & individuo==individuo[_n-12]
		replace evento=27 if evento[_n-13]==14 & individuo==individuo[_n-13]
	
*Generate inactive spells duration
sort individuo anio
gen duracionI1=duracionSpell[_n-1] if evento==14
bysort individuo: egen duracionIT=mean(duracionI1)
drop duracionI1

*Generate year-out variable (last year before inactive spell)
gen syear_out=anio if evento==13
bysort individuo: egen year_out=mean(syear_out)
drop syear_out

*Generate 2008-2009 crisis variable
gen crisis2009=cond((year_out==2008 | year_out==2009),1,0)

*Generate cohort and indsutry-year groups
gen cohorte = anio - age + 18
egen indus_year = group(actividad2 anio)

*Restrict to a balanced panel (3-year or 5-year window)
	*Three-year window
		gen sMenosTres=1 if evento==11	 
		bysort individuo: egen MenosTres=mean(sMenosTres)	 
		drop sMenosTres
		gen sMasTres=1 if evento==16	 
		bysort individuo: egen MasTres=mean(sMasTres)	 
		drop sMasTres
		gen Tres=cond((MasTres+MenosTres)==2,1,0)
		drop  MenosTres MasTres

	*Five-year window
		sort individuo anio
		gen sMenosCinco=1 if evento==9	 
		bysort individuo: egen MenosCinco=mean(sMenosCinco)	 
		drop sMenosCinco
		gen sMasCinco=1 if evento==18	 
		bysort individuo: egen MasCinco=mean(sMasCinco)	 
		drop sMasCinco
		gen Cinco=cond((MasCinco+MenosCinco)==2,1,0)
		drop  MenosCinco MasCinco


*Labels
	
	label var evento     `"Event window"'
	label define evento_lbl 0 `"t=-13"'
	label define evento_lbl 1 `"t=-12"', add
	label define evento_lbl 2 `"t=-11"', add
	label define evento_lbl 3 `"t=-10"', add
	label define evento_lbl 4 `"t=-9"', add
	label define evento_lbl 5 `"t=-8"', add
	label define evento_lbl 6 `"t=-7"', add
	label define evento_lbl 7 `"t=-6"', add
	label define evento_lbl 8 `"t=-5"', add
	label define evento_lbl 9 `"t=-4"', add
	label define evento_lbl 10 `"t=-3"', add
	label define evento_lbl 11 `"t=-2"', add
	label define evento_lbl 12 `"t=-1"', add
	label define evento_lbl 13 `"t=0"', add
	label define evento_lbl 14 `"t=1"', add
	label define evento_lbl 15 `"t=2"', add
	label define evento_lbl 16 `"t=3"', add
	label define evento_lbl 17 `"t=4"', add
	label define evento_lbl 18 `"t=5"', add
	label define evento_lbl 19 `"t=6"', add
	label define evento_lbl 20 `"t=7"', add
	label define evento_lbl 21 `"t=8"', add
	label define evento_lbl 22 `"t=9"', add
	label define evento_lbl 23 `"t=10"', add
	label define evento_lbl 24 `"t=11"', add
	label define evento_lbl 25 `"t=12"', add
	label define evento_lbl 26 `"t=13"', add
	label define evento_lbl 27 `"t=14"', add
	label values evento evento_lbl

	label var duracionIT     `"Duration of inactive spell"'
	label define duracionIT_lbl 1 `"1 year"'
	label define duracionIT_lbl 2 `"2 years"', add
	label define duracionIT_lbl 3 `"3 years"', add
	label define duracionIT_lbl 4 `"4 years"', add
	label define duracionIT_lbl 5 `"5 years"', add
	label define duracionIT_lbl 6 `"6 years"', add
	label define duracionIT_lbl 7 `"7 years"', add
	label define duracionIT_lbl 8 `"8 years"', add
	label define duracionIT_lbl 9 `"9 years"', add
	label define duracionIT_lbl 10 `"10 years"', add
	label define duracionIT_lbl 11 `"11 years"', add
	label define duracionIT_lbl 12 `"12 years"', add
	label define duracionIT_lbl 13 `"13 years"', add
	label values duracionIT  duracionIT_lbl
	
	label var crisis2009   `"2009 Crisis"'
	label define crisis2009_lbl 0 `"2009Crisis=0"'
	label define crisis2009_lbl 1 `"2009Crisis=1"', add
	label values crisis2009  crisis2009_lbl


save "$constructeddata/transitions_treateds2.dta", replace

	
/* End of do-file */			
	







