/*===========================================================================
Project:  Inequality, Income Dynamics, and Worker Transitions:The Case of Mexico
Author:   Daniela Puggioni, Mariana Calderón, Alfonso Cebreros Zurita, León
Fernández Bujanda, José Antonio Inguanzo González, and David Jaume 
Program name: 14.plot_appendix.do
Dependencies: Banco de Mexico
Description: Produces figures included in the appendix
===========================================================================*/

glo carpeta 	     "S:\PartB\B.1TransitionsInOutIMSS\Replication"
glo sourcedata	     "$carpeta/data/source"
glo constructeddata	 "$carpeta/data/constructed"
glo figures 	     "$carpeta/figures"
glo logfiles	     "$carpeta/log"
glo ster		     "$carpeta/ster"
glo tables		     "$carpeta/tables"
glo code	         "$carpeta/code"




*Figure D1	(fixed effects)
clear
estimates use  "$ster/M_logdif_clusteredFE"
estimate store M_logdif_clusteredFE
estimates use  "$ster/F_logdif_clusteredFE"
estimate store F_logdif_clusteredFE

coefplot (M_logdif_clusteredFE, label(Male) msymbol(D) mcolor(blue)) 	    ///
	(F_logdif_clusteredFE, label(Female) mcolor(red)), vertical keep(*.evento) ///
	omitted baselevels ciopts (recast(rcap)) msize(small) 			///
	title("")  ytitle("") xtitle("Year before leaving the sample: t=0") 	///
	graphregion(color(white)) bgcolor(white) note("") 						///
	yline(0, lcolor(black) lpattern(dash))                                 ///
	ylabel(-0.15 (0.05) 0.05)												///
	xlabel(1 "t=-2" 2 "t=-1" 3 "t=0" 4 "t=1" 5 "t=2" 6 "t=3", 				///
	angle(vertical) grid) 													///
	plotregion(lcolor(black)) legend(ring(0) position(8) cols(1) bmargin(large)) ///
	saving("$figures/D1.logdif_clusteredFE.gph", replace)	                  
	graph export "$figures/D1.logdif_clusteredFE.pdf", as(pdf) replace


*Figure D2  (margins fixed effects)
use "$constructeddata/transitions_treated.dta", replace
keep if Tres==1
keep if evento>=11 & evento<=16	
	*Males
	estimates use  "$ster/M_levels_clusteredFE"
	estimate store M_logdif_clusteredFE
	estimates esample: lsbcReal evento duracionIT age actividad2 entidad anio 	///
		if sex==1
	eststo M_levels_clusteredFE: margins ib13.event#i.duracionIT, expression(predict(xb)) ///
		at(age = 25 actividad2=1 entidad== 1 anio=2005) noestimcheck post
	coefplot (M_levels_clusteredFE, mcolor(blue)), vertical                     ///
	    ciopts(recast(rcap) lcolor(navy)) graphregion(color(white)) 	        ///
		bgcolor(white) xtitle("Year before leaving the sample: t=0") 			///
		xline(9.5 18.5 27.5 36.5 45.5, lpattern(dash) lcolor(black)) 			///
		xlabel(5 "t=-2" 14 "t=-1" 23 "t=0" 32 "t=1" 41 "t=2" 50 "t=3", 			///
		angle(vertical)) plotregion(lcolor(black)) 								///
		ylabel(8.2 (0.1) 8.6)                      							    ///
		saving("$figures/D2.M_levels_clusteredFE.gph", replace)                  
		graph export "$figures/D2.M_levels_clusteredFE.pdf", as(pdf) replace
	*Females
	estimates use  "$ster/F_levels_clusteredFE"
	estimate store F_logdif_clusteredF
	estimates esample: lsbcReal evento duracionIT age actividad2 entidad anio 	///
		if sex==0
	eststo F_levels_clusteredFE: margins ib13.event#i.duracionIT, expression(predict(xb)) ///
		at(age = 25 actividad2=1 entidad== 1 anio=2005) noestimcheck post
	coefplot (F_levels_clusteredFE, mcolor(red)), vertical                     ///
	    ciopts(recast(rcap) lcolor(maroon)) graphregion(color(white)) 	        ///
		bgcolor(white) xtitle("Year before leaving the sample: t=0") 			///
		xline(9.5 18.5 27.5 36.5 45.5, lpattern(dash) lcolor(black)) 			///
		xlabel(5 "t=-2" 14 "t=-1" 23 "t=0" 32 "t=1" 41 "t=2" 50 "t=3", 			///
		angle(vertical)) plotregion(lcolor(black)) 								///
		ylabel(8.2 (0.1) 8.6)                      							    ///
		saving("$figures/D2.F_levels_clusteredFE.gph", replace)                  
		graph export "$figures/D2.F_levels_clusteredFE.pdf", as(pdf) replace

*Figure D3 (cohort)
clear
estimates use  "$ster/M_logdif_clusteredCOH"
estimate store M_logdif_clusteredCOH
estimates use  "$ster/F_logdif_clusteredCOH"
estimate store F_logdif_clusteredCOH

coefplot (M_logdif_clusteredCOH, label(Male) msymbol(D) mcolor(blue)) 	    ///
	(F_logdif_clusteredCOH, label(Female) mcolor(red)), vertical keep(*.evento) ///
	omitted baselevels ciopts (recast(rcap)) msize(small) 			///
	title("")  ytitle("") xtitle("Year before leaving the sample: t=0") 	///
	graphregion(color(white)) bgcolor(white) note("") 						///
	yline(0, lcolor(black) lpattern(dash))                                 ///
	ylabel(-0.15 (0.05) 0.05)												///
	xlabel(1 "t=-2" 2 "t=-1" 3 "t=0" 4 "t=1" 5 "t=2" 6 "t=3", 				///
	angle(vertical) grid) 													///
	plotregion(lcolor(black)) legend(ring(0) position(8) cols(1) bmargin(large)) ///
	saving("$figures/D3.logdif_clusteredCOH.gph", replace)	                   
	graph export "$figures/D3.logdif_clusteredCOH.pdf", as(pdf) replace

*Figure D4: Five-year event window
clear
estimates use  "$ster/M_logdif_clustered5y"
estimate store M_logdif_clustered5y
estimates use  "$ster/F_logdif_clustered5y"
estimate store F_logdif_clustered5y

coefplot (M_logdif_clustered5y, label(Male) msymbol(D) mcolor(blue)) 	    ///
	(F_logdif_clustered5y, label(Female) mcolor(red)), vertical keep(*.evento) ///
	omitted baselevels ciopts (recast(rcap)) msize(small) 			///
	title("")  ytitle("") xtitle("Year before leaving the sample: t=0") 	///
	graphregion(color(white)) bgcolor(white) note("") 						///
	yline(0, lcolor(black) lpattern(dash))                                 ///
	ylabel(-0.2 (0.05) 0.15)												///
	xlabel(1 "t=-4" 2 "t=-3" 3 "t=-2" 4 "t=-1" 5 "t=0" 6 "t=1" 7 "t=2"      ///
	8 "t=3" 9 "t=4" 10 "t=5", angle(vertical) grid) 						///
	plotregion(lcolor(black)) legend(ring(0) position(8) cols(1) bmargin(large)) ///
	saving("$figures/D4.logdif_clustered5y.gph", replace)	                   
	graph export "$figures/D4.logdif_clustered5y.pdf", as(pdf) replace

*Figure D5: Augmented sample 
clear
estimates use  "$ster/M_logdif_clustereds2"
estimate store M_logdif_clustereds2
estimates use  "$ster/F_logdif_clustereds2"
estimate store F_logdif_clustereds2

coefplot (M_logdif_clustereds2, label(Male) msymbol(D) mcolor(blue)) 	    ///
	(F_logdif_clustereds2, label(Female) mcolor(red)), vertical keep(*.evento) ///
	omitted baselevels ciopts (recast(rcap)) msize(small) 			///
	title("")  ytitle("") xtitle("Year before leaving the sample: t=0") 	///
	graphregion(color(white)) bgcolor(white) note("") 						///
	yline(0, lcolor(black) lpattern(dash))                                 ///
	ylabel(-.2 (0.05) 0.1)												   ///
	xlabel(1 "t=-2" 2 "t=-1" 3 "t=0" 4 "t=1" 5 "t=2" 6 "t=3", 				///
	angle(vertical) grid) 													///
	plotregion(lcolor(black)) legend(ring(0) position(8) cols(1) bmargin(large)) ///
	saving("$figures/D5.logdif_clustereds2.gph", replace)	                   
	graph export "$figures/D5.logdif_clustereds2.pdf", as(pdf) replace

*Figure D6: Financial crisis
use "$constructeddata/transitions_treated.dta", replace	
keep if Tres==1
keep if evento>=11 & evento<=16	
*Males
	estimates use  "$ster/M_logdif_crisisclustered3y"
	estimate store M_logdif_crisisclustered3
	estimates esample: lsbcReal evento crisis2009 age actividad2 entidad anio 	///
		if sex==1
	eststo M_levels_crisis: margins ib13.event#i.crisis2009, expression(predict(xb)) ///
		at(age = 25 actividad2=1 entidad== 1 anio=2005) noestimcheck post
	coefplot (M_levels_crisis, mcolor(blue)), vertical ciopts(recast(rcap) lcolor(navy)) ///
		graphregion(color(white)) 	                                            ///
		bgcolor(white) xtitle("Year before leaving the sample: t=0") 			///
		xline(2.5 4.5 6.5 8.5 10.5, lpattern(dash) lcolor(black)) 				///
		xlabel(1 "t=-2*2009Crisis=0" 2 "t=-2*2009Crisis=1" 3 "t=-1*2009Crisis=0" ///
		4 "t=-1*2009Crisis=1" 5 "t=0*2009Crisis=0" 6 "t=0*2009Crisis=1"			///
		7 "t=1*2009Crisis=0" 8 "t=1*2009Crisis=1" 9 "t=2*2009Crisis=0" 			///
		10 "t=2*2009Crisis=1" 11 "t=3*2009Crisis=0" 12 "t=3*2009Crisis=1", 		///
		angle(vertical)) plotregion(lcolor(black)) ylabel(7.8 (0.1) 8.3) 		///
		plotregion(lcolor(black))							                    ///
		saving("$figures/D6.M_logdif_crisisclustered3y.gph", replace)             
		graph export "$figures/D6.M_logdif_crisisclustered3y.pdf", as(pdf) replace
	*Females
		estimates use  "$ster/F_logdif_crisisclustered3y"
		estimate store F_logdif_crisisclustered3
			estimates esample: lsbcReal evento crisis2009 age actividad2 entidad anio 	///
		if sex==0
	eststo F_levels_crisis: margins ib13.event#i.crisis2009, expression(predict(xb)) 	///
		at(age = 25 actividad2=1 entidad== 1 anio=2005) noestimcheck post
	coefplot (F_levels_crisis,mcolor(red)), vertical ciopts(recast(rcap) lcolor(maroon)) ///
		graphregion(color(white)) 	                                            ///
		bgcolor(white) xtitle("Year before leaving the sample: t=0") 			///
		xline(2.5 4.5 6.5 8.5 10.5, lpattern(dash) lcolor(black)) 				///
		xlabel(1 "t=-2*2009Crisis=0" 2 "t=-2*2009Crisis=1" 3 "t=-1*2009Crisis=0" ///
		4 "t=-1*2009Crisis=1" 5 "t=0*2009Crisis=0" 6 "t=0*2009Crisis=1"			///
		7 "t=1*2009Crisis=0" 8 "t=1*2009Crisis=1" 9 "t=2*2009Crisis=0" 			///
		10 "t=2*2009Crisis=1" 11 "t=3*2009Crisis=0" 12 "t=3*2009Crisis=1", 		///
		angle(vertical)) plotregion(lcolor(black)) ylabel(7.8 (0.1) 8.3) 		///
		plotregion(lcolor(black))						                      	///
		saving("$figures/D6.F_logdif_crisisclustered3y.gph", replace)             
		graph export "$figures/D6.F_logdif_crisisclustered3y.pdf", as(pdf) replace
		
		
/* End of do-file */	