
/*===========================================================================
Project:  Inequality, Income Dynamics, and Worker Transitions:The Case of Mexico
Author:   Daniela Puggioni, Mariana Calderón, Alfonso Cebreros Zurita, León
Fernández Bujanda, José Antonio Inguanzo González, and David Jaume 
Program name: 2.build_imss_panel_recover.do
Dependencies: Banco de Mexico
Description: Recovers number of months a worker was present per year in IMSS 
database, state and economic activity
===========================================================================*/

set more off
clear all


glo carpeta 	     "S:\PartB\B.1TransitionsInOutIMSS\Replication"
glo sourcedata	      "J:"
glo constructeddata	 "$carpeta/data/constructed"
glo figures 	     "$carpeta/figures"
glo logfiles	     "$carpeta/log"
glo ster		     "$carpeta/ster"
glo tables		     "$carpeta/tables"
glo code	         "$carpeta/code"


local anio "2005 2006 2007 2008 2009 2010 2011 2012 2013 2014 2015 2016 2017 2018 2019"
local mes "01 02 03 04 05 06 07 08 09 10 11 12"
foreach a of local anio{
	foreach m of local mes{
		
		*Load raw IMSS microdata
		use "$sourcedata/stata/`a'/imss_`m'`a'.dta", clear
		rename *, lower
		drop llave_tiempo  llave_sexo tipo_trabajador llave_municipio
		rename salariof          sbc
		rename llave_empleado    nss
		rename llave_empresa     registro
		rename llave_entidad     entidad
		rename llave_actividad   actividad
		rename llave_modalidad   modalidad
		
		gen anio=`a'
		gen mes=`m'
		
		sort registro nss 	

		*Workers may have duplicates in one month. We keep the observation with 
		*the highest wage per month (proxy for primary job)
		bysort nss: egen double maxsbc=max(sbc)
		keep if sbc==maxsbc
		drop maxsbc
		
		*Dropping remaining duplicates (workers may have duplicates with the 
		*same wage)
		duplicates drop nss, force
		drop registro 
		
		*Drop workers without income
		drop if sbc==. | sbc==0
		drop sbc
		

		save 	"$constructeddata/IMSS`m'`a'.dta", replace
	}
	
	
	*Append monthly files
	use "$constructeddata/IMSS01`a'.dta", replace
	local mes2 "02 03 04 05 06 07 08 09 10 11 12"
	foreach m2 of local mes2{
		append using "$constructeddata/IMSS`m2'`a'.dta"
	}
	
	
	
	*Generate worker-level variables per year
	
	*# of months workers were present during a year
	sort nss mes
	bysort nss: gen smesesActivo=_n
	bysort nss: egen mesesActivo=max(smesesActivo)
	
	*Economic activity and state (mode during the year)
	local var "actividad entidad modalidad"
	foreach v of local var{
		bysort nss: egen Mode`v'=mode(`v')
		gen saux`v'=`v' if smesesActivo==mesesActivo
		bysort nss: egen aux`v'=max(saux`v')
		replace Mode`v'=aux`v' if Mode`v'==.
		drop aux`v' saux`v'
	}
	

	*Keep annual data
	duplicates drop nss, force
	
	drop mes entidad actividad modalidad  smesesActivo 
	
	rename Modeactividad actividad
	rename Modeentidad  entidad
	rename Modemodalidad modalidad
	

	local mes "01 02 03 04 05 06 07 08 09 10 11 12"
	foreach m of local mes{
		erase "$constructeddata/IMSS`m'`a'.dta"
	}
	
	save "$constructeddata/IMSS`a'", replace
}

/* End of do-file */	