/*===========================================================================
Project:  Inequality, Income Dynamics, and Worker Transitions:The Case of Mexico
Author:   Daniela Puggioni, Mariana Calderón, Alfonso Cebreros Zurita, León
Fernández Bujanda, José Antonio Inguanzo González, and David Jaume 
Program name: 5.build_transitions_treated_and_control.do
Dependencies: Banco de Mexico
Description: Builds control group
===========================================================================*/

glo carpeta 	     "S:\PartB\B.1TransitionsInOutIMSS\Replication"
glo sourcedata	     "$carpeta/data/source"
glo constructeddata	 "$carpeta/data/constructed"
glo figures 	     "$carpeta/figures"
glo logfiles	     "$carpeta/log"
glo ster		     "$carpeta/ster"
glo tables		     "$carpeta/tables"
glo code	         "$carpeta/code"

*Bring spells data
use "$constructeddata/spells.dta", replace

*Keep workers with 1 inactive spell (= only 2 active spells) or with the ones which stayed all years for which data is available
keep if spellsInactivo==1	| (spellsActivo==1 & duracionSpell==15)
sort individuo anio

*Generate treatment group	
gen treated=cond(spellsInactivo==1,1,0)

*Set up basis for generating control group 
	*Evento (0,1,2,3,4,5)
	*Evento=2, Last observed wage before exit 
	*Evento=3, first observed wage when comming back
	gen evento=.
	replace evento=2 if _spell==1 & _end==1  & treated==1
	replace evento=3 if _spell==3 & _seq==1  & treated==1
	replace evento=0 if evento[_n+2]==2 & individuo==individuo[_n+2]  & treated==1
	replace evento=1 if evento[_n+1]==2 & individuo==individuo[_n+1]  & treated==1
	replace evento=4 if evento[_n-1]==3 & individuo==individuo[_n-1]  & treated==1
	replace evento=5 if evento[_n-2]==3 & individuo==individuo[_n-2]  & treated==1

	
*Generate inactive spells duration
sort individuo anio
gen duracionI1=duracionSpell[_n-1] if evento==3
bysort individuo: egen duracionIT=mean(duracionI1)
drop duracionI1

*Generate year-out variable (last year before inactive spell)	
gen syear_out=anio if evento==2
bysort individuo: egen year_out=mean(syear_out)
drop syear_out
	

tempfile AnalisisMatching
save 	"`AnalisisMatching'", replace
	
*CEM command for control group (http://gking.harvard.edu/cem/)
ssc install cem

*Keep characteristics of the treatment group in the year before exiting	
keep if (evento==2 & treated==1) | treated==0

keep individuo anio age sex actividad2 entidad treated
order individuo anio age sex actividad2 entidad treated
gsort -treated individuo anio

cem anio (#0) age (24.5 30.5 35.5 40.5 45.5 50.5 55.5) sex (#0)  actividad2 (#0) entidad (#0) , treatment(treated) k2k
	
save "$constructeddata/CemMatching.dta", replace
	
gsort -cem_matched cem_strata
		
*Generate random number to assign matches within strata 
keep if cem_matched==1
drop  cem_weights cem_matched
	
set seed 2038947
generate random = runiform()
	
sort cem_strata treated random
bysort cem_strata treated: gen par=_n
gsort cem_strata par -treated
bysort cem_strata par: gen conteo=_n
gen match=individuo[_n-1]
replace match=. if conteo==1
	
rename anio year_out
drop age sex actividad2 entidad random conteo
	
tempfile CemMatches
save "`CemMatches'", replace
	
		
*Controls have duplicates. One worker could be matched with many workers in the treatment group in different years before exiting 
preserve
	keep if treated==0
	duplicates tag individuo, gen(tag)
	tab tag, m
	drop tag par

	gen anio=year_out
	sort individuo anio

	tab anio, m
		*2018 & 2019 are missing to have all years between 2005-2019
	*Generate fake 2018 & 2019		
	set obs 501149
	replace individuo = 999999 in 501148
	replace anio = 2018 in 501148
	replace individuo = 999999 in 501149
	replace anio = 2019 in 501149

	*Generate fake history, as if controls were different individuals
		egen fake_id=group(individuo anio)		
		tsset fake_id anio
		tsfill, full
		sort fake_id anio
		bysort fake_id: egen individuo2=mean(individuo)	
		bysort fake_id: egen match2=mean(match)	
		bysort fake_id: egen year_out2=mean(year_out)	
		bysort fake_id: egen treated2=mean(treated)	
		drop individuo year_out treated cem_strata match
		rename individuo2 individuo
		rename match2 match
		rename year_out2 year_out
		rename treated2 treated
		order fake_id individuo anio match year_out treated
		drop if individuo==999999 
		
		*Recover wage history from the control group
		merge m:1 individuo anio using 	"`AnalisisMatching'"
		drop if _merge==2
		drop _merge
			
		sort fake_id anio	

		drop nss actividad modalidad yob activo _spell _seq _end sActivo spellsActivo sInactivo spellsInactivo duracion duracionSpell evento  duracionIT
		order fake_id individuo anio match year_out treated lsbcReal age sex actividad2 entidad wage_anual_obs mesesActivo INPCanual SBCmensual SBCmensualReal	
	
		tempfile ControlGroup
		save "`ControlGroup'", replace	
restore

*Keep workers in the treatment group with matches in the control group
keep if treated==1
keep individuo year_out treated
rename year_out year_out2
tempfile TreatmentGroup1
save "`TreatmentGroup1'", replace
	

*Recover wages history from the treatment group (with matches in the control group)
use 	"`AnalisisMatching'", replace
keep if spellsInactivo==1
sort individuo anio
drop nss actividad modalidad yob activo  sActivo spellsActivo sInactivo spellsInactivo duracion duracionSpell 
order individuo anio evento duracionIT year_out treated lsbcReal age sex actividad2 entidad wage_anual_obs mesesActivo INPCanual SBCmensual SBCmensualReal	
	
merge m:1 individuo using "`TreatmentGroup1'"
keep if _merge==3
drop _merge
	
*Generate all possible events for the treatment group 
drop evento
sort individuo anio		
	gen evento=.
	*Last observed wage before exit 
	replace evento=13 if _spell==1 & _end==1 
	*First observed wage when comming back
	replace evento=14 if _spell==3 & _seq==1
	*Before exiting IMSS
	replace evento=0 if evento[_n+13]==13 & individuo==individuo[_n+13]
	replace evento=1 if evento[_n+12]==13 & individuo==individuo[_n+12]
	replace evento=2 if evento[_n+11]==13 & individuo==individuo[_n+11]
	replace evento=3 if evento[_n+10]==13 & individuo==individuo[_n+10]
	replace evento=4 if evento[_n+9]==13  & individuo==individuo[_n+9]
	replace evento=5 if evento[_n+8]==13  & individuo==individuo[_n+8]
	replace evento=6 if evento[_n+7]==13  & individuo==individuo[_n+7]
	replace evento=7 if evento[_n+6]==13  & individuo==individuo[_n+6]
	replace evento=8 if evento[_n+5]==13  & individuo==individuo[_n+5]
	replace evento=9 if evento[_n+4]==13  & individuo==individuo[_n+4]
	replace evento=10 if evento[_n+3]==13  & individuo==individuo[_n+3]
	replace evento=11 if evento[_n+2]==13  & individuo==individuo[_n+2]
	replace evento=12 if evento[_n+1]==13  & individuo==individuo[_n+1]
	*When coming back
	replace evento=15 if evento[_n-1]==14 & individuo==individuo[_n-1]
	replace evento=16 if evento[_n-2]==14 & individuo==individuo[_n-2]
	replace evento=17 if evento[_n-3]==14 & individuo==individuo[_n-3]
	replace evento=18 if evento[_n-4]==14 & individuo==individuo[_n-4]
	replace evento=19 if evento[_n-5]==14 & individuo==individuo[_n-5]
	replace evento=20 if evento[_n-6]==14 & individuo==individuo[_n-6]
	replace evento=21 if evento[_n-7]==14 & individuo==individuo[_n-7]
	replace evento=22 if evento[_n-8]==14 & individuo==individuo[_n-8]
	replace evento=23 if evento[_n-9]==14 & individuo==individuo[_n-9]
	replace evento=24 if evento[_n-10]==14 & individuo==individuo[_n-10]
	replace evento=25 if evento[_n-11]==14 & individuo==individuo[_n-11]
	replace evento=26 if evento[_n-12]==14 & individuo==individuo[_n-12]
	replace evento=27 if evento[_n-13]==14 & individuo==individuo[_n-13]

order individuo anio evento duracionIT year_out	
tempfile TreatmentGroup2
save "`TreatmentGroup2'", replace
	
*Keep inactive spells' duration for constructing fake inactive spells for the control group
keep individuo duracionIT year_out
duplicates drop individuo, force
rename individuo match
rename year_out year_out2	
tempfile RecuperarDuracion
save "`RecuperarDuracion'", replace
		
*Create fake events for the control group, based on the inactive spells duration from the treatment group
use "`ControlGroup'", replace
	
merge m:1 match using "`RecuperarDuracion'"
drop _merge
order fake_id anio duracionIT year_out
sort fake_id anio
gen year_return=year_out+duracionIT+1
		
*Generate fake events
gen evento=13 if anio==year_out
replace evento=14 if anio==year_return	
	*Before exiting IMSS
	replace evento=0 if evento[_n+13]==13 & fake_id==fake_id[_n+13]
	replace evento=1 if evento[_n+12]==13 & fake_id==fake_id[_n+12]
	replace evento=2 if evento[_n+11]==13 & fake_id==fake_id[_n+11]
	replace evento=3 if evento[_n+10]==13 & fake_id==fake_id[_n+10]
	replace evento=4 if evento[_n+9]==13  & fake_id==fake_id[_n+9]
	replace evento=5 if evento[_n+8]==13  & fake_id==fake_id[_n+8]
	replace evento=6 if evento[_n+7]==13  & fake_id==fake_id[_n+7]
	replace evento=7 if evento[_n+6]==13  & fake_id==fake_id[_n+6]
	replace evento=8 if evento[_n+5]==13  & fake_id==fake_id[_n+5]
	replace evento=9 if evento[_n+4]==13  & fake_id==fake_id[_n+4]
	replace evento=10 if evento[_n+3]==13  & fake_id==fake_id[_n+3]
	replace evento=11 if evento[_n+2]==13  & fake_id==fake_id[_n+2]
	replace evento=12 if evento[_n+1]==13  & fake_id==fake_id[_n+1]
	*When coming back
	replace evento=15 if evento[_n-1]==14 & fake_id==fake_id[_n-1]
	replace evento=16 if evento[_n-2]==14 & fake_id==fake_id[_n-2]
	replace evento=17 if evento[_n-3]==14 & fake_id==fake_id[_n-3]
	replace evento=18 if evento[_n-4]==14 & fake_id==fake_id[_n-4]
	replace evento=19 if evento[_n-5]==14 & fake_id==fake_id[_n-5]
	replace evento=20 if evento[_n-6]==14 & fake_id==fake_id[_n-6]
	replace evento=21 if evento[_n-7]==14 & fake_id==fake_id[_n-7]
	replace evento=22 if evento[_n-8]==14 & fake_id==fake_id[_n-8]
	replace evento=23 if evento[_n-9]==14 & fake_id==fake_id[_n-9]
	replace evento=24 if evento[_n-10]==14 & fake_id==fake_id[_n-10]
	replace evento=25 if evento[_n-11]==14 & fake_id==fake_id[_n-11]
	replace evento=26 if evento[_n-12]==14 & fake_id==fake_id[_n-12]
	replace evento=27 if evento[_n-13]==14 & fake_id==fake_id[_n-13]
	
	order fake_id individuo anio evento duracionIT year_out
	
	
	*Send to missing all values in the years when the control group is asusmed to be in its inactive spell 
	local var "lsbcReal age sex actividad2 entidad wage_anual_obs mesesActivo INPCanual SBCmensual SBCmensualReal"
		foreach v of local var{
		replace `v'=. if evento==.
	}		

	drop year_return	


*Bring back treatment group	
append using "`TreatmentGroup2'"
drop _spell _seq _end
	
egen fake_id2=group(individuo  year_out)
order fake_id2
sort fake_id2 anio
drop fake_id
rename fake_id2 fake_id
gsort -treated fake_id anio

*Generate cohort and industry-year groups
gen cohorte = anio - age + 18
egen indus_year = group(actividad2 anio)   

*Restrict to a balanced panel (3-year or 5-year window)
gen sMenosTres=1 if evento==11	 
bysort fake_id: egen MenosTres=mean(sMenosTres)	 
drop sMenosTres
gen sMasTres=1 if evento==16	 
bysort fake_id: egen MasTres=mean(sMasTres)	 
drop sMasTres
gen Tres=cond((MasTres+MenosTres)==2,1,0)
drop  MenosTres MasTres

*Five-year window
gsort -treated fake_id anio
gen sMenosCinco=1 if evento==9	 
bysort fake_id: egen MenosCinco=mean(sMenosCinco)	 
drop sMenosCinco
gen sMasCinco=1 if evento==18	 
bysort fake_id: egen MasCinco=mean(sMasCinco)	 
drop sMasCinco
gen Cinco=cond((MasCinco+MenosCinco)==2,1,0)
drop  MenosCinco MasCinco

gsort -treated fake_id anio


*Labels
	
	label var evento     `"Event window"'
	label define evento_lbl 0 `"t=-13"'
	label define evento_lbl 1 `"t=-12"', add
	label define evento_lbl 2 `"t=-11"', add
	label define evento_lbl 3 `"t=-10"', add
	label define evento_lbl 4 `"t=-9"', add
	label define evento_lbl 5 `"t=-8"', add
	label define evento_lbl 6 `"t=-7"', add
	label define evento_lbl 7 `"t=-6"', add
	label define evento_lbl 8 `"t=-5"', add
	label define evento_lbl 9 `"t=-4"', add
	label define evento_lbl 10 `"t=-3"', add
	label define evento_lbl 11 `"t=-2"', add
	label define evento_lbl 12 `"t=-1"', add
	label define evento_lbl 13 `"t=0"', add
	label define evento_lbl 14 `"t=1"', add
	label define evento_lbl 15 `"t=2"', add
	label define evento_lbl 16 `"t=3"', add
	label define evento_lbl 17 `"t=4"', add
	label define evento_lbl 18 `"t=5"', add
	label define evento_lbl 19 `"t=6"', add
	label define evento_lbl 20 `"t=7"', add
	label define evento_lbl 21 `"t=8"', add
	label define evento_lbl 22 `"t=9"', add
	label define evento_lbl 23 `"t=10"', add
	label define evento_lbl 24 `"t=11"', add
	label define evento_lbl 25 `"t=12"', add
	label define evento_lbl 26 `"t=13"', add
	label define evento_lbl 27 `"t=14"', add
	label values evento evento_lbl
	
	label var treated  `"Treatment"'
	label define treated_lbl 0 `"Treated=0"'
	label define treated_lbl 1 `"Treated=1"', add
	label values treated treated_lbl

save "$constructeddata/transitions_treated_and_control.dta", replace	

/* End of do-file */			
	







