/*===========================================================================
Project:  Inequality, Income Dynamics, and Worker Transitions:The Case of Mexico
Author:   Daniela Puggioni, Mariana Calderón, Alfonso Cebreros Zurita, León
Fernández Bujanda, José Antonio Inguanzo González, and David Jaume 
Program name: 6.est_baseline_3yearwindow.do
Dependencies: Banco de Mexico
Description: Produces estimates included in section 3.2 of the paper
===========================================================================*/

glo carpeta 	     "S:\PartB\B.1TransitionsInOutIMSS\Replication"
glo sourcedata	     "$carpeta/data/source"
glo constructeddata	 "$carpeta/data/constructed"
glo figures 	     "$carpeta/figures"
glo logfiles	     "$carpeta/log"
glo ster		     "$carpeta/ster"
glo tables		     "$carpeta/tables"
glo code	         "$carpeta/code"

*Bring transitions from treatment group: workers with 1 inactive spell (only 2 active spells)
use "$constructeddata/transitions_treated.dta", replace

	*Three-year window
		keep if Tres==1
		keep if evento>=11 & evento<=16
		
	*Equation 4.1 (Figures 16 & 17) 
		log using "$logfiles/logdif_clustered3y.log", replace
				
			di "Estimates of wages trajectories (log differences) of workers who exit and re-enter formal employment"
		
				di "Male"
				reghdfe lsbcReal ib13.event##i.duracionIT i.age  i.actividad2 i.entidad ///
					i.anio  if sex==1, vce(cluster individuo indus_year) noabsorb 
				estimates save  "$ster/M_logdif_clustered3y", replace
				
				di "Female"
				reghdfe lsbcReal ib13.event##i.duracionIT i.age i.actividad2 i.entidad 	///
					i.anio if sex==0, vce(cluster  individuo indus_year) noabsorb
				estimates save  "$ster/F_logdif_clustered3y", replace
				
		log close

	
		
		
	*Equation 4.2 (Figure 18)	
		*Bring transitions from treatment and control group
		use "$constructeddata/transitions_treated_and_control.dta", replace			
			
			*Three-year window
				keep if Tres==1
				keep if evento>=11 & evento<=16


				log using "$logfiles/treatment_control_clustered3y.log", replace
					
					di "Estimates of wages trajectories: treatment vs control group"
						
						di "Male"
						reghdfe lsbcReal ib13.evento##treated i.age i.actividad2 i.entidad 		///
							i.anio if sex==1, vce(cluster individuo indus_year) noabsorb
						estimates save  "$ster/M_treatment_control_clustered3y", replace
						
						di "Female"
						reghdfe lsbcReal ib13.evento##treated i.age i.actividad2 i.entidad 		///
							i.anio if sex==0, vce(cluster individuo indus_year) noabsorb
						estimates save  "$ster/F_treatment_control_clustered3y", replace
						
				log close
			
	/* End of do-file */	
	
	

	







