/*===========================================================================
Project:  Inequality, Income Dynamics, and Worker Transitions:The Case of Mexico
Author:   Daniela Puggioni, Mariana Calderón, Alfonso Cebreros Zurita, León
Fernández Bujanda, José Antonio Inguanzo González, and David Jaume 
Program name: 7.plot_baseline_3yearwindow.do
Dependencies: Banco de Mexico
Description: Produces figures included in section 3.2 of the paper
===========================================================================*/

glo carpeta 	     "S:\PartB\B.1TransitionsInOutIMSS\Replication"
glo sourcedata	     "$carpeta/data/source"
glo constructeddata	 "$carpeta/data/constructed"
glo figures 	     "$carpeta/figures"
glo logfiles	     "$carpeta/log"
glo ster		     "$carpeta/ster"
glo tables		     "$carpeta/tables"
glo code	         "$carpeta/code"



*Figure 16
clear
estimates use  "$ster/M_logdif_clustered3y"
estimate store M_logdif_clustered3y
estimates use  "$ster/F_logdif_clustered3y"
estimate store F_logdif_clustered3y

coefplot (M_logdif_clustered3y, label(Male) msymbol(D) mcolor(blue)) 	    ///
	(F_logdif_clustered3y, label(Female) mcolor(red)), vertical keep(*.evento) ///
	omitted baselevels ciopts (recast(rcap)) msize(small) 			///
	title("")  ytitle("") xtitle("Year before leaving the sample: t=0") 	///
	graphregion(color(white)) bgcolor(white) note("") 						///
	yline(0, lcolor(black) lpattern(dash))                                 ///
	ylabel(-0.15 (0.05) 0.05)												///
	xlabel(1 "t=-2" 2 "t=-1" 3 "t=0" 4 "t=1" 5 "t=2" 6 "t=3", 				///
	angle(vertical) grid) 													///
	plotregion(lcolor(black)) legend(ring(0) position(8) cols(1) bmargin(large)) ///
	saving("$figures/F16.logdif_clustered3y.gph", replace)	
	graph export "$figures/F16.logdif_clustered3y.pdf", as(pdf) replace
	
*Figure 17 
use "$constructeddata/transitions_treated.dta", replace
keep if Tres==1
keep if evento>=11 & evento<=16
	*Males
	estimates use  "$ster/M_logdif_clustered3y"
	estimate store M_logdif_clustered3y
	estimates esample: lsbcReal evento duracionIT age actividad2 entidad anio 	///
		if sex==1
	eststo M_levels_clustered3y: margins ib13.event#i.duracionIT, expression(predict(xb)) ///
		at(age = 25 actividad2=1 entidad== 1 anio=2005) noestimcheck post
	coefplot (M_levels_clustered3y, mcolor(blue)), vertical                      ///
	ciopts(recast(rcap) lcolor(navy)) graphregion(color(white)) 	            ///
		bgcolor(white) xtitle("Year before leaving the sample: t=0") 			///
		xline(9.5 18.5 27.5 36.5 45.5, lpattern(dash) lcolor(black)) 			///
		xlabel(5 "t=-2" 14 "t=-1" 23 "t=0" 32 "t=1" 41 "t=2" 50 "t=3", 			///
		angle(vertical)) plotregion(lcolor(black)) 								///
		ylabel(7.8 (0.1) 8.3)       							                ///
		saving("$figures/F17.M_levels_clustered3y.gph", replace)                    
		graph export "$figures/F17.M_levels_clustered3y.pdf", as(pdf) replace
		
	*Females
	estimates use  "$ster/F_logdif_clustered3y"
	estimate store F_logdif_clustered3y
	estimates esample: lsbcReal evento duracionIT age actividad2 entidad anio 	///
		if sex==0
	eststo F_levels_clustered3y: margins ib13.event#i.duracionIT, expression(predict(xb)) ///
		at(age = 25 actividad2=1 entidad== 1 anio=2005) noestimcheck post
	coefplot (F_levels_clustered3y, mcolor(red)), vertical                      ///
	ciopts(recast(rcap) lcolor(maroon)) graphregion(color(white)) 	            ///
		bgcolor(white) xtitle("Year before leaving the sample: t=0") 			///
		xline(9.5 18.5 27.5 36.5 45.5, lpattern(dash) lcolor(black)) 			///
		xlabel(5 "t=-2" 14 "t=-1" 23 "t=0" 32 "t=1" 41 "t=2" 50 "t=3", 			///
		angle(vertical)) plotregion(lcolor(black)) 								///
		ylabel(7.8 (0.1) 8.3)                      							///
		saving("$figures/F17.F_levels_clustered3y.gph", replace)                    
		graph export "$figures/F17.F_levels_clustered3y.pdf", as(pdf) replace
		 


*Figure 18 
use "$constructeddata/transitions_treated_and_control.dta", replace	
keep if Tres==1
keep if evento>=11 & evento<=16	
	*Males
	estimates use  "$ster/M_treatment_control_clustered3y"
	estimate store M_tc_clustered3y
	estimates esample: lsbcReal evento treated age actividad2 entidad anio 		///
		if sex==1
	eststo M_treat_cont_clust3y: margins ib13.evento#treated, expression(predict(xb)) noestimcheck ///
		at(age = 25 actividad2=1 entidad== 1 anio=2005) post
	coefplot (M_treat_cont_clust3y, mcolor(blue)), vertical                      ///
	ciopts(recast(rcap) lcolor(navy)) graphregion(color(white)) 	            ///
		bgcolor(white) xtitle("Year before leaving the sample: t=0") 			///
		xline(2.5 4.5 6.5 8.5 10.5, lpattern(dash) lcolor(black)) 				///
		ylabel(7.8 (0.2) 8.6)                                                   ///
		xlabel(1 "t=-2*Treated=0" 2 "t=-2*Treated=1" 3 "t=-1*Treated=0" 		///
		4 "t=-1*Treated=1" 5 "t=0*Treated=0" 6 "t=0*Treated=1" 					///
		7 "t=1*Treated=0" 8 "t=1*Treated=1" 9 "t=2*Treated=0" 10 "t=2*Treated=1" ///
		11 "t=3*Treated=0" 12 "t=3*Treated=1", angle(vertical)) 				///
		plotregion(lcolor(black))						                      	///
		saving("$figures/F18.M_treatment_control_clustered3y.gph", replace)         
		graph export "$figures/F18.M_treatment_control_clustered3y.pdf", as(pdf) replace
	*Females
	estimates use  "$ster/F_treatment_control_clustered3y"
	estimate store F_tc_clustered3y
	estimates esample: lsbcReal evento treated age actividad2 entidad anio 		///
		if sex==0
	eststo F_treat_cont_clust3y: margins ib13.evento#treated, expression(predict(xb)) noestimcheck ///
		at(age = 25 actividad2=1 entidad== 1 anio=2005) post
	coefplot (F_treat_cont_clust3y, mcolor(red)), vertical                      ///
	ciopts(recast(rcap) lcolor(maroon)) graphregion(color(white)) 	            ///
		bgcolor(white) xtitle("Year before leaving the sample: t=0") 			///
		xline(2.5 4.5 6.5 8.5 10.5, lpattern(dash) lcolor(black)) 				///
		ylabel(7.8 (0.2) 8.6)                                                   ///
		xlabel(1 "t=-2*Treated=0" 2 "t=-2*Treated=1" 3 "t=-1*Treated=0" 		///
		4 "t=-1*Treated=1" 5 "t=0*Treated=0" 6 "t=0*Treated=1" 					///
		7 "t=1*Treated=0" 8 "t=1*Treated=1" 9 "t=2*Treated=0" 10 "t=2*Treated=1" ///
		11 "t=3*Treated=0" 12 "t=3*Treated=1", angle(vertical)) 				///
		plotregion(lcolor(black))						                      	///
		saving("$figures/F18.F_treatment_control_clustered3y.gph", replace)         
		graph export "$figures/F18.F_treatment_control_clustered3y.pdf", as(pdf) replace
		 

		
/* End of do-file */	