/*===========================================================================
Project:  Inequality, Income Dynamics, and Worker Transitions:The Case of Mexico
Author:   Daniela Puggioni, Mariana Calderón, Alfonso Cebreros Zurita, León
Fernández Bujanda, José Antonio Inguanzo González, and David Jaume 
Program name: 9.est_fixedeffects.do
Dependencies: Banco de Mexico
Description: Produces estimates with worker fixed effects
===========================================================================*/

glo carpeta 	     "S:\PartB\B.1TransitionsInOutIMSS\Replication"
glo sourcedata	     "$carpeta/data/source"
glo constructeddata	 "$carpeta/data/constructed"
glo figures 	     "$carpeta/figures"
glo logfiles	     "$carpeta/log"
glo ster		     "$carpeta/ster"
glo tables		     "$carpeta/tables"
glo code	         "$carpeta/code"

*Bring transitions from treatment group: workers with 1 inactive spell (only 2 active spells)
use "$constructeddata/transitions_treated.dta", replace

	*Three-year window
		keep if Tres==1
		keep if evento>=11 & evento<=16
		

	*Figure D1
		log using "$logfiles/logdif_clusteredFE.log", replace
				
			di "Estimates of wages trajectories (log differences) of workers who exit and re-enter formal employment including worker fixed effects"
		
				di "Male"
				reghdfe lsbcReal ib13.event i.age  i.actividad2 i.entidad ///
					i.anio  if sex==1, vce(cluster individuo indus_year) absorb(individuo)
				estimates save  "$ster/M_logdif_clusteredFE", replace
				
				di "Female"
				reghdfe lsbcReal ib13.event i.age i.actividad2 i.entidad 	///
					i.anio if sex==0, vce(cluster  individuo indus_year) absorb(individuo)
				estimates save  "$ster/F_logdif_clusteredFE", replace
				
		log close

	*Figure D2 
	log using "$logfiles/levels_clusteredFE.log", replace
				
		di "Estimates of wages trajectories (log differences) of workers who exit and re-enter formal employment including worker fixed effects"
		
			di "Male"
			reghdfe lsbcReal ib13.event##i.duracionIT i.age  i.actividad2 i.entidad ///
				i.anio  if sex==1, vce(cluster individuo indus_year) absorb(individuo)
			estimates save  "$ster/M_levels_clusteredFE", replace
				
			di "Female"
			reghdfe lsbcReal ib13.event##i.duracionIT i.age i.actividad2 i.entidad 	///
				i.anio if sex==0, vce(cluster  individuo indus_year) absorb(individuo)
			estimates save  "$ster/F_levels_clusteredFE", replace
				
		log close
		
		
	*Figure D3
	log using "$logfiles/logdif_clusteredCOH.log", replace
				
		di "Estimates of wages trajectories (log differences) of workers who exit and re-enter formal employment including cohort-year fixed effects "
		
			di "Male"
			reghdfe lsbcReal ib13.event i.age  i.actividad2 i.entidad 	        ///
				i.anio##i.cohorte if sex==1, vce(cluster individuo indus_year) noabsorb
			estimates save  "$ster/M_logdif_clusteredCOH", replace
			di "Female"
				reghdfe lsbcReal ib13.event i.age i.actividad2 i.entidad 		///
				i.anio##i.cohorte if sex==0, 	vce(cluster  individuo indus_year) noabsorb
			estimates save  "$ster/F_logdif_clusteredCOH", replace
				
		log close


		
	
			
	/* End of do-file */	
	
	

	







